summaryrefslogtreecommitdiff
path: root/vcl
diff options
context:
space:
mode:
authorKurt Zenker <kz@openoffice.org>2003-11-18 15:04:04 +0000
committerKurt Zenker <kz@openoffice.org>2003-11-18 15:04:04 +0000
commite8640770fe9b955d59413e21c2b19a43d91aace9 (patch)
tree6641531dbb157cb21602972f1d72c51932a7cca2 /vcl
parent66a78628173454930bc00dcfa1dad9ed08d646c5 (diff)
#100000# solve mergeconflicts
Diffstat (limited to 'vcl')
-rw-r--r--vcl/unx/inc/salframe.h6
-rw-r--r--vcl/unx/inc/salinst.h8
-rw-r--r--vcl/unx/source/window/salmenu.cxx14
-rw-r--r--vcl/win/inc/salinst.h8
-rw-r--r--vcl/win/source/window/salmenu.cxx14
5 files changed, 30 insertions, 20 deletions
diff --git a/vcl/unx/inc/salframe.h b/vcl/unx/inc/salframe.h
index 706c8a531d6e..9063b8d5dc14 100644
--- a/vcl/unx/inc/salframe.h
+++ b/vcl/unx/inc/salframe.h
@@ -2,9 +2,9 @@
*
* $RCSfile: salframe.h,v $
*
- * $Revision: 1.32 $
+ * $Revision: 1.33 $
*
- * last change: $Author: kz $ $Date: 2003-11-18 14:37:43 $
+ * last change: $Author: kz $ $Date: 2003-11-18 16:01:06 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -270,6 +270,8 @@ public:
virtual void SetTitle( const XubString& rTitle );
virtual void SetIcon( USHORT nIcon );
+ virtual void SetMenu( SalMenu* pMenu );
+ virtual void DrawMenuBar();
virtual void Show( BOOL bVisible, BOOL bNoActivate = FALSE );
virtual void Enable( BOOL bEnable );
diff --git a/vcl/unx/inc/salinst.h b/vcl/unx/inc/salinst.h
index d8907c1a4588..84f2b05628c0 100644
--- a/vcl/unx/inc/salinst.h
+++ b/vcl/unx/inc/salinst.h
@@ -2,9 +2,9 @@
*
* $RCSfile: salinst.h,v $
*
- * $Revision: 1.5 $
+ * $Revision: 1.6 $
*
- * last change: $Author: kz $ $Date: 2003-11-18 14:38:10 $
+ * last change: $Author: kz $ $Date: 2003-11-18 16:01:06 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -138,6 +138,10 @@ public:
virtual void Yield( BOOL bWait );
virtual bool AnyInput( USHORT nType );
+ virtual SalMenu* CreateMenu( BOOL bMenuBar );
+ virtual void DestroyMenu( SalMenu* pMenu);
+ virtual SalMenuItem* CreateMenuItem( const SalItemParams* pItemData );
+ virtual void DestroyMenuItem( SalMenuItem* pItem );
virtual void* GetConnectionIdentifier( ConnectionIdentifierType& rReturnedType, int& rReturnedBytes );
diff --git a/vcl/unx/source/window/salmenu.cxx b/vcl/unx/source/window/salmenu.cxx
index 514306a38e57..baa0637e540f 100644
--- a/vcl/unx/source/window/salmenu.cxx
+++ b/vcl/unx/source/window/salmenu.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: salmenu.cxx,v $
*
- * $Revision: 1.2 $
+ * $Revision: 1.3 $
*
- * last change: $Author: kz $ $Date: 2003-11-18 14:58:07 $
+ * last change: $Author: kz $ $Date: 2003-11-18 16:02:17 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -75,25 +75,25 @@
// =======================================================================
-// SalInst factory methods
+// X11SalInst factory methods
-SalMenu* SalInstance::CreateMenu( BOOL bMenuBar )
+SalMenu* X11SalInstance::CreateMenu( BOOL bMenuBar )
{
return NULL; // no support for native menues
}
-void SalInstance::DestroyMenu( SalMenu* pSalMenu )
+void X11SalInstance::DestroyMenu( SalMenu* pSalMenu )
{
delete pSalMenu;
}
-SalMenuItem* SalInstance::CreateMenuItem( const SalItemParams* pItemData )
+SalMenuItem* X11SalInstance::CreateMenuItem( const SalItemParams* pItemData )
{
return NULL; // no support for native menues
}
-void SalInstance::DestroyMenuItem( SalMenuItem* pSalMenuItem )
+void X11SalInstance::DestroyMenuItem( SalMenuItem* pSalMenuItem )
{
delete pSalMenuItem;
}
diff --git a/vcl/win/inc/salinst.h b/vcl/win/inc/salinst.h
index 049400aea892..2745815053b5 100644
--- a/vcl/win/inc/salinst.h
+++ b/vcl/win/inc/salinst.h
@@ -2,9 +2,9 @@
*
* $RCSfile: salinst.h,v $
*
- * $Revision: 1.5 $
+ * $Revision: 1.6 $
*
- * last change: $Author: kz $ $Date: 2003-11-18 14:48:59 $
+ * last change: $Author: kz $ $Date: 2003-11-18 16:03:21 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -120,6 +120,10 @@ public:
virtual void AcquireYieldMutex( ULONG nCount );
virtual void Yield( BOOL bWait );
virtual bool AnyInput( USHORT nType );
+ virtual SalMenu* CreateMenu( BOOL bMenuBar );
+ virtual void DestroyMenu( SalMenu* );
+ virtual SalMenuItem* CreateMenuItem( const SalItemParams* pItemData );
+ virtual void DestroyMenuItem( SalMenuItem* );
virtual void* GetConnectionIdentifier( ConnectionIdentifierType& rReturnedType, int& rReturnedBytes );
};
diff --git a/vcl/win/source/window/salmenu.cxx b/vcl/win/source/window/salmenu.cxx
index cb0e8dd8abde..20f5cf1760f8 100644
--- a/vcl/win/source/window/salmenu.cxx
+++ b/vcl/win/source/window/salmenu.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: salmenu.cxx,v $
*
- * $Revision: 1.2 $
+ * $Revision: 1.3 $
*
- * last change: $Author: kz $ $Date: 2003-11-18 14:58:57 $
+ * last change: $Author: kz $ $Date: 2003-11-18 16:04:04 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -102,9 +102,9 @@ static DWORD myerr=0;
// =======================================================================
-// SalInst factory methods
+// WinSalInst factory methods
-SalMenu* SalInstance::CreateMenu( BOOL bMenuBar )
+SalMenu* WinSalInstance::CreateMenu( BOOL bMenuBar )
{
SalMenu *pSalMenu = new SalMenu();
@@ -118,13 +118,13 @@ SalMenu* SalInstance::CreateMenu( BOOL bMenuBar )
return pSalMenu;
}
-void SalInstance::DestroyMenu( SalMenu* pSalMenu )
+void WinSalInstance::DestroyMenu( SalMenu* pSalMenu )
{
delete pSalMenu;
}
-SalMenuItem* SalInstance::CreateMenuItem( const SalItemParams* pItemData )
+SalMenuItem* WinSalInstance::CreateMenuItem( const SalItemParams* pItemData )
{
if( !pItemData )
return NULL;
@@ -167,7 +167,7 @@ SalMenuItem* SalInstance::CreateMenuItem( const SalItemParams* pItemData )
return pSalMenuItem;
}
-void SalInstance::DestroyMenuItem( SalMenuItem* pSalMenuItem )
+void WinSalInstance::DestroyMenuItem( SalMenuItem* pSalMenuItem )
{
delete pSalMenuItem;
}